@@ -1,14 +1,19 @@
 from .machine import Machine
 from .connection import Connection
-from .plugin import Plugin, PluginResult
+from .plugin import Plugin
 from .resource import Resource
 from .path import Path
+from .test_client import TestClient
+from .params import Parameters
+from .types import PluginGenerator
 
 __all__ = [
     'Machine',
     'Connection',
     'Plugin',
-    'PluginResult',
     'Resource',
     'Path',
+    'TestClient',
+    'Parameters',
+    'PluginGenerator'
 ]
