@@ -1,8 +1,10 @@
 from .connection import MachineConnectionError
 from .connection import ConnectionClosed
+from .machine import MachineError
 
 
 __all__ = [
+    'MachineError',
     'MachineConnectionError',
     'ConnectionClosed'
 ]
