@@ -1,6 +1,7 @@
 import typing
 
-from machine.plugin import Plugin
+from machine.connection import Connection
+from machine.params import Parameters
 
 Scope = typing.MutableMapping[str, typing.Any]
 Message = typing.MutableMapping[str, typing.Any]
@@ -9,4 +10,6 @@ Receive = typing.Callable[[], typing.Awaitable[Message]]
 Send = typing.Callable[[Message], typing.Awaitable[None]]
 
 ASGIApp = typing.Callable[[Scope, Receive, Send], typing.Awaitable[None]]
-PluginGenerator = typing.Callable[[], Plugin]
+
+PluginType = typing.Callable[[Connection, Parameters], typing.AsyncIterator[typing.Tuple[Connection, Parameters]]]
+PluginGenerator = typing.Callable[[], PluginType]
